@@ -38,7 +38,13 @@ from ensureconda import ensureconda
 from typing_extensions import Literal
 
 from conda_lock.click_helpers import OrderedGroup
-from conda_lock.common import read_file, read_json, relative_path, write_file
+from conda_lock.common import (
+    read_file,
+    read_json,
+    relative_path,
+    temporary_file_with_contents,
+    write_file,
+)
 from conda_lock.conda_solver import solve_conda
 from conda_lock.errors import MissingEnvVarError, PlatformValidationError
 from conda_lock.invoke_conda import (
@@ -57,6 +63,7 @@ try:
 except ImportError:
     PIP_SUPPORT = False
 from conda_lock.src_parser import (
+    Dependency,
     LockedDependency,
     Lockfile,
     LockMeta,
@@ -208,9 +215,8 @@ def do_conda_install(
     if not pip_requirements:
         return
 
-    with tempfile.NamedTemporaryFile() as tf:
-        write_file("\n".join(pip_requirements), tf.name)
-        _conda(["run"], ["pip", "install", "--no-deps", "-r", tf.name])
+    with temporary_file_with_contents("\n".join(pip_requirements)) as requirements_path:
+        _conda(["run"], ["pip", "install", "--no-deps", "-r", str(requirements_path)])
 
 
 def fn_to_dist_name(fn: str) -> str:
@@ -229,8 +235,9 @@ def make_lock_spec(
     virtual_package_repo: FakeRepoData,
     channel_overrides: Optional[Sequence[str]] = None,
     platform_overrides: Optional[Sequence[str]] = None,
+    required_categories: Optional[AbstractSet[str]] = None,
 ) -> LockSpecification:
-    """Generate the lockfile specs from a set of input src_files"""
+    """Generate the lockfile specs from a set of input src_files.  If required_categories is set filter out specs that do not match those"""
     lock_specs = parse_source_files(
         src_files=src_files, platform_overrides=platform_overrides or DEFAULT_PLATFORMS
     )
@@ -246,10 +253,22 @@ def make_lock_spec(
         list(platform_overrides) if platform_overrides else lock_spec.platforms
     ) or list(DEFAULT_PLATFORMS)
 
+    if required_categories is not None:
+
+        def dep_has_category(d: Dependency, categories: AbstractSet[str]) -> bool:
+            return d.category in categories
+
+        lock_spec.dependencies = [
+            d
+            for d in lock_spec.dependencies
+            if dep_has_category(d, categories=required_categories)
+        ]
+
     return lock_spec
 
 
 def make_lock_files(
+    *,
     conda: PathLike,
     src_files: List[pathlib.Path],
     kinds: Sequence[TKindAll],
@@ -260,6 +279,7 @@ def make_lock_files(
     update: Optional[List[str]] = None,
     include_dev_dependencies: bool = True,
     filename_template: Optional[str] = None,
+    filter_categories: bool = True,
     extras: Optional[AbstractSet[str]] = None,
     check_input_hash: bool = False,
 ) -> None:
@@ -291,6 +311,8 @@ def make_lock_files(
         Format for names of rendered explicit or env files. Must include {platform}.
     extras :
         Include the given extras in explicit or env output
+    filter_categories :
+        Filter out unused categories prior to solving
     check_input_hash :
         Do not re-solve for each target platform for which specifications are unchanged
     """
@@ -303,14 +325,20 @@ def make_lock_files(
     else:
         virtual_package_repo = default_virtual_package_repodata()
 
+    required_categories = {"main"}
+    if include_dev_dependencies:
+        required_categories.add("dev")
+    if extras is not None:
+        required_categories.update(extras)
+
     with virtual_package_repo:
         lock_spec = make_lock_spec(
             src_files=src_files,
             channel_overrides=channel_overrides,
             platform_overrides=platform_overrides,
             virtual_package_repo=virtual_package_repo,
+            required_categories=required_categories if filter_categories else None,
         )
-
         lock_content: Optional[Lockfile] = None
 
         platforms_to_lock: List[str] = []
@@ -767,15 +795,8 @@ def _add_auth_to_lockfile(lockfile: str, auth: Dict[str, str]) -> str:
 @contextmanager
 def _add_auth(lockfile: str, auth: Dict[str, str]) -> Iterator[pathlib.Path]:
     lockfile_with_auth = _add_auth_to_lockfile(lockfile, auth)
-
-    # On Windows, NamedTemporaryFiles can't be opened a second time, so we have to close it first (and delete it manually later)
-    tf = tempfile.NamedTemporaryFile(delete=False)
-    try:
-        tf.close()
-        write_file(lockfile_with_auth, tf.name)
-        yield pathlib.Path(tf.name)
-    finally:
-        os.unlink(tf.name)
+    with temporary_file_with_contents(lockfile_with_auth) as path:
+        yield path
 
 
 def _strip_auth_from_line(line: str) -> str:
@@ -854,21 +875,20 @@ def _render_lockfile_for_install(
             f"Cannot run render lockfile.  Missing environment variables: {msg}"
         )
 
-    with tempfile.NamedTemporaryFile(mode="w") as tf:
-        content = render_lockfile_for_platform(
-            lockfile=lock_content,
-            kind="explicit",
-            platform=platform,
-            include_dev_dependencies=include_dev_dependencies,
-            extras=extras,
-        )
-        tf.write("\n".join(content) + "\n")
-        tf.flush()
-        yield pathlib.Path(tf.name)
+    content = render_lockfile_for_platform(
+        lockfile=lock_content,
+        kind="explicit",
+        platform=platform,
+        include_dev_dependencies=include_dev_dependencies,
+        extras=extras,
+    )
+    with temporary_file_with_contents("\n".join(content) + "\n") as path:
+        yield path
 
 
 def run_lock(
     environment_files: List[pathlib.Path],
+    *,
     conda_exe: Optional[str],
     platforms: Optional[List[str]] = None,
     mamba: bool = False,
@@ -882,6 +902,7 @@ def run_lock(
     extras: Optional[AbstractSet[str]] = None,
     virtual_package_spec: Optional[pathlib.Path] = None,
     update: Optional[List[str]] = None,
+    filter_categories: bool = False,
 ) -> None:
     if environment_files == DEFAULT_FILES:
         if lockfile_path.exists():
@@ -925,6 +946,7 @@ def run_lock(
         include_dev_dependencies=include_dev_dependencies,
         extras=extras,
         check_input_hash=check_input_hash,
+        filter_categories=filter_categories,
     )
 
 
@@ -1012,10 +1034,18 @@ TLogLevel = Union[
 @click.option(
     "-e",
     "--extras",
+    "--category",
     default=[],
     type=str,
     multiple=True,
-    help="When used in conjunction with input sources that support extras (pyproject.toml) will add the deps from those extras to the input specification",
+    help="When used in conjunction with input sources that support extras/categories (pyproject.toml) will add the deps from those extras to the render specification",
+)
+@click.option(
+    "--filter-categories",
+    "--filter-extras",
+    is_flag=True,
+    default=False,
+    help="In conjunction with extras this will prune out dependencies that do not have the extras specified when loading files.",
 )
 @click.option(
     "--check-input-hash",
@@ -1057,6 +1087,7 @@ def lock(
     lockfile: PathLike,
     strip_auth: bool,
     extras: List[str],
+    filter_categories: bool,
     check_input_hash: bool,
     log_level: TLogLevel,
     pdb: bool,
@@ -1120,6 +1151,7 @@ def lock(
         extras=extras_,
         virtual_package_spec=virtual_package_spec,
         update=update,
+        filter_categories=filter_categories,
     )
     if strip_auth:
         with tempfile.TemporaryDirectory() as tempdir:
