@@ -1,9 +1,13 @@
+import logging
 import re
 
 from typing import Iterator
 
 
-def filter_platform_selectors(content: str, platform) -> Iterator[str]:
+logger = logging.getLogger(__name__)
+
+
+def filter_platform_selectors(content: str, platform: str) -> Iterator[str]:
     """ """
     # we support a very limited set of selectors that adhere to platform only
     platform_sel = {
@@ -16,14 +20,18 @@ def filter_platform_selectors(content: str, platform) -> Iterator[str]:
     }
 
     # This code is adapted from conda-build
-    sel_pat = re.compile(r"(.+?)\s*(#.*)?\[([^\[\]]+)\](?(2)[^\(\)]*)$")
+    sel_pat = re.compile(r"(.+?)\s*(#.*)\[([^\[\]]+)\](?(2)[^\(\)]*)$")
     for line in content.splitlines(keepends=False):
         if line.lstrip().startswith("#"):
             continue
         m = sel_pat.match(line)
         if m:
             cond = m.group(3)
-            if cond in platform_sel[platform]:
+            if platform and (cond in platform_sel[platform]):
                 yield line
+            else:
+                logger.warning(
+                    "filtered out line `%s` due to unmatchable selector", line
+                )
         else:
             yield line
