@@ -39,7 +39,7 @@ from conda_lock.conda_lock import (
     parse_meta_yaml_file,
     run_lock,
 )
-from conda_lock.conda_solver import fake_conda_environment
+from conda_lock.conda_solver import extract_json_object, fake_conda_environment
 from conda_lock.errors import (
     ChannelAggregationError,
     MissingEnvVarError,
@@ -343,6 +343,39 @@ def test_parse_poetry(poetry_pyproject_toml):
     assert res.channels == [Channel.from_string("defaults")]
 
 
+def test_spec_poetry(poetry_pyproject_toml):
+
+    virtual_package_repo = default_virtual_package_repodata()
+    with virtual_package_repo:
+        spec = make_lock_spec(
+            src_files=[poetry_pyproject_toml], virtual_package_repo=virtual_package_repo
+        )
+        deps = {d.name for d in spec.dependencies}
+        assert "tomlkit" in deps
+        assert "pytest" in deps
+        assert "requests" in deps
+
+        spec = make_lock_spec(
+            src_files=[poetry_pyproject_toml],
+            virtual_package_repo=virtual_package_repo,
+            required_categories={"main", "dev"},
+        )
+        deps = {d.name for d in spec.dependencies}
+        assert "tomlkit" not in deps
+        assert "pytest" in deps
+        assert "requests" in deps
+
+        spec = make_lock_spec(
+            src_files=[poetry_pyproject_toml],
+            virtual_package_repo=virtual_package_repo,
+            required_categories={"main"},
+        )
+        deps = {d.name for d in spec.dependencies}
+        assert "tomlkit" not in deps
+        assert "pytest" not in deps
+        assert "requests" in deps
+
+
 def test_parse_flit(flit_pyproject_toml):
     res = parse_pyproject_toml(
         flit_pyproject_toml,
@@ -1159,3 +1192,9 @@ def test_private_lock(quetz_server, tmp_path, monkeypatch, capsys, conda_exe):
     monkeypatch.delenv("QUETZ_API_KEY")
     with pytest.raises(MissingEnvVarError):
         run_install()
+
+
+def test_extract_json_object():
+    """It should remove all the characters after the last }"""
+    assert extract_json_object(' ^[0m {"key1": true } ^[0m') == '{"key1": true }'
+    assert extract_json_object('{"key1": true }') == '{"key1": true }'
